summaryrefslogtreecommitdiffstats
path: root/chromium/third_party/webrtc/modules/video_capture/android/device_info_android.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/webrtc/modules/video_capture/android/device_info_android.h')
-rw-r--r--chromium/third_party/webrtc/modules/video_capture/android/device_info_android.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/chromium/third_party/webrtc/modules/video_capture/android/device_info_android.h b/chromium/third_party/webrtc/modules/video_capture/android/device_info_android.h
index d277113e5e1..542cbba0881 100644
--- a/chromium/third_party/webrtc/modules/video_capture/android/device_info_android.h
+++ b/chromium/third_party/webrtc/modules/video_capture/android/device_info_android.h
@@ -24,6 +24,7 @@ namespace videocapturemodule
class DeviceInfoAndroid : public DeviceInfoImpl {
public:
static void Initialize(JNIEnv* env);
+ static void DeInitialize();
DeviceInfoAndroid(int32_t id);
virtual ~DeviceInfoAndroid();
@@ -53,10 +54,12 @@ class DeviceInfoAndroid : public DeviceInfoImpl {
virtual int32_t GetOrientation(const char* deviceUniqueIdUTF8,
VideoCaptureRotation& orientation);
- // Populate |min_mfps| and |max_mfps| with the supported range of the device.
- void GetFpsRange(const char* deviceUniqueIdUTF8,
- int* min_mfps,
- int* max_mfps);
+ // Populate |min_mfps| and |max_mfps| with the closest supported range of the
+ // device to |max_fps_to_match|.
+ void GetMFpsRange(const char* deviceUniqueIdUTF8,
+ int max_fps_to_match,
+ int* min_mfps,
+ int* max_mfps);
private:
enum { kExpectedCaptureDelay = 190};